from setuptools import setup

setup(
    name="pylists",
    version="0.0.1.1",
    url="https://github.com/DOG-E",
    author="DOG-E",
    author_email="DogeUserBot@gmail.com",
    description=("Lists"),
    packages=["pylists"],
    classifiers=[
        "Operating System :: OS Independent",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 2",
    ],
)
